@@ -1,3 +1,4 @@
 pub mod custom_lang;
-mod prompts;
+pub mod prompts;
 mod basic_prompts;
+mod update;
